@@ -3,16 +3,16 @@
 use std::cell::UnsafeCell;
 use std::collections::HashMap;
 use std::fmt::{self, Debug, Formatter};
+use std::future::Future;
 use std::net::{IpAddr, SocketAddr};
 use std::pin::Pin;
 use std::ptr;
 use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
+use std::task::{Context, Poll};
 
 use crate::grpc_sys::{self, grpc_call_error, grpc_server};
-use futures::future::Future;
-use futures::ready;
-use futures::task::{Context, Poll};
+use futures_util::ready;
 
 use crate::call::server::*;
 use crate::call::{MessageReader, Method, MethodType};
@@ -77,7 +77,7 @@ fn join_host_port(host: &str, port: u16) -> String {
     }
 }
 
-#[cfg(feature = "secure")]
+#[cfg(feature = "_secure")]
 mod imp {
     use super::join_host_port;
     use crate::grpc_sys::{self, grpc_server};
@@ -135,7 +135,7 @@ mod imp {
     }
 }
 
-#[cfg(not(feature = "secure"))]
+#[cfg(not(feature = "_secure"))]
 mod imp {
     use super::join_host_port;
     use crate::grpc_sys::{self, grpc_server};
@@ -396,7 +396,7 @@ impl ServerBuilder {
     }
 }
 
-#[cfg(feature = "secure")]
+#[cfg(feature = "_secure")]
 mod secure_server {
     use super::{Binder, ServerBuilder};
     use crate::grpc_sys;
@@ -494,6 +494,7 @@ impl RequestCallContext {
 
 // Apparently, its life time is guaranteed by the ref count, hence is safe to be sent
 // to other thread. However it's not `Sync`, as `BoxHandler` is unnecessarily `Sync`.
+#[allow(clippy::non_send_fields_in_send_ty)]
 unsafe impl Send for RequestCallContext {}
 
 /// Request notification of a new call.
@@ -520,7 +521,7 @@ pub fn request_call(ctx: RequestCallContext, cq: &CompletionQueue) {
         )
     };
     if code != grpc_call_error::GRPC_CALL_OK {
-        Box::from(tag);
+        drop(Box::from(tag));
         panic!("failed to request call: {:?}", code);
     }
 }
@@ -635,7 +636,7 @@ impl Drop for Server {
             None
         };
         self.cancel_all_calls();
-        let _ = f.map(futures::executor::block_on);
+        let _ = f.map(futures_executor::block_on);
     }
 }
 
